@@ -4,6 +4,9 @@ Demo_DAWGI_HBM
 Age-metallicity inference of a simple stellar population.
 """
 
-__version__ = "0.1.0"
+__version__ = "0.1.2"
 __author__ = 'Jairo Andrés Alzate Trujillo'
 __credits__ = 'Instituto de Radioastronómia y Astrofísica, Universidad Nacional Autónoma de México'
+
+from . import SFH_Sampling
+__all__ = ['SFH_Sampling']
